# -*- Mode: rpm-spec -*-
#
# (c) Mandriva
#
# The kernel-2.6-linus package (and so this spec file) is under development,
# it does mean:
#
#    1. You can have nasty surprises when playing with the package
#    generation
#
#    2. Is easier to go and come back from Mordor than adding a new
#    architecture support
#
#    3. A known architecture with just a missing .config shouldn't be too
#    hard, but as this spec changes too fast, it's likely to be broken
# 
#
# if you try to understand kernel numbering, read docs/kernel_naming

%define sublevel 17
%define mdkrelease 1
%define use_patch 0
#define patchlevel 1
%define klinus_notice NOTE: This kernel has no Mandriva patches and no third-party drivers.

# This is only to make life easier for people that creates derivated kernels
# a.k.a name it kernel-tmb :)
%define kname kernel-linus

# You shouldn't have to change any other name/patch/version number
%define major 6

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %use_patch
%define kversion 2.%{major}.%(expr %{sublevel} - 1)
%define realrelease %{use_patch}.%{mdkrelease}%{?patchlevel:.%{patchlevel}}mdv
%else
%define kversion 2.%{major}.%{sublevel}
%define realrelease %{mdkrelease}%{?patchlevel:.%{patchlevel}}mdv
%endif

# never touch the folowing two fields
%define rpmversion 1
%define rpmrelease 1mdv2007.0
%define krealversion 2.%{major}.%{sublevel}
%define mdkversion %{krealversion}.%{realrelease}

# having different top level names for packges means
# that you have to remove them by hard :(
%define top_dir_name %{kname}-2.%{major}

%define build_dir ${RPM_BUILD_DIR}/%top_dir_name
%define src_dir %{build_dir}/linux-%kversion
%define KVERREL %{krealversion}-%{realrelease}

%define build_kheaders 0
%define build_debug 0
%define build_doc 1
%define build_source 1

%define distro_branch %(perl -pe '/(\\d+)\\.(\\d)\\.?(\\d)?/; $_="$1.$2"' /etc/mandrake-release)
%define build_101 %(if [ `awk '{print $4}' /etc/mandrake-release` = 10.1 ];then echo 1; else echo 0; fi)
%define build_100 %(if [ `awk '{print $4}' /etc/mandrake-release` = 10.0 ];then echo 1; else echo 0; fi)
%define build_92 %(if [ `awk '{print $4}' /etc/mandrake-release` = 9.2 ];then echo 1; else echo 0; fi)

%define build_up 1
%define build_smp 1

%define build_secure 0

%ifarch %{ix86}
%define build_i586_up_1GB 0
%define build_i686_up_4GB 0
%define build_xbox 0
%else
%define build_i586_up_1GB 0
%define build_i686_up_4GB 0
%define build_xbox 0
%endif

%ifarch powerpc
%define build_power5 1
%define build_ppc970 0
%if ! %{build_ppc970}
# default to build for power5 only
%define build_up     0
%define build_smp    0
%endif
%else
%define build_power5 0
%endif

# End of user definitions
%{?_without_up: %global build_up 0}
%{?_without_smp: %global build_smp 0}
%{?_without_secure: %global build_secure 0}
%{?_without_i586up1GB: %global build_i586_up_1GB 0}
%{?_without_i686up4GB: %global build_i686_up_4GB 0}
%{?_without_xbox: %global build_xbox 0}
%{?_without_debug: %global build_debug 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}

%{?_with_up: %global build_up 1}
%{?_with_smp: %global build_smp 1}
%{?_with_secure: %global build_secure 1}
%{?_with_i586up1GB: %global build_i586_up_1GB 1}
%{?_with_i686up4GB: %global build_i686_up_4GB 1}
%{?_with_xbox: %global build_xbox 1}
%{?_with_debug: %global build_debug 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}

%{?_with_kheaders: %global build_kheaders 1}
%{?_with_92: %global build_92 1}
%{?_with_100: %global build_100 1}
%{?_with_101: %global build_101 1}

%if %(if [ -z "$CC" ] ; then echo 0; else echo 1; fi)
%define kmake %make CC="$CC"
%else
%define kmake %make 
%endif
# there are places where parallel make don't work
%define smake make

# Aliases for amd64 builds (better make source links?)
%define target_cpu	%(echo %{_target_cpu} | sed -e "s/amd64/x86_64/")
%define target_arch	%(echo %{_arch} | sed -e "s/amd64/x86_64/")

Summary: The Linux kernel (the core of the Linux operating system).
Name: %{kname}-%{mdkversion}
Version: %{rpmversion}
Release: %{rpmrelease}
License: GPL
Group: System/Kernel and hardware
ExclusiveArch: %{ix86} alpha ppc powerpc ia64 x86_64 amd64 sparc sparc64
ExclusiveOS: Linux
URL: http://www.kernel.org/

####################################################################
#
# Sources
#
Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.%{major}/linux-%{kversion}.tar.bz2
Source1: ftp://ftp.kernel.org/pub/linux/kernel/v2.%{major}/linux-%{kversion}.tar.bz2.sign
Source4: README.kernel-sources
Source5: README.MandrivaLinux
Source15: linux-mdkconfig.h
Source16: linux-merge-config.awk
Source17: update_configs
Source20: kernel-%{kversion}-i386.config
Source21: kernel-%{kversion}-i386-smp.config
Source22: kernel-%{kversion}-x86_64.config
Source23: kernel-%{kversion}-x86_64-smp.config
Source24: kernel-%{kversion}-sparc64.config
Source25: kernel-%{kversion}-sparc64-smp.config
Source26: kernel-%{kversion}-ppc.config
Source27: kernel-%{kversion}-ppc-smp.config


####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v2.%{major}/testing

%if %use_patch
Patch1: patch-%krealversion-%use_patch.bz2
%endif

#END
####################################################################

# Defines for the things that are needed for all the kernels
%define requires1 module-init-tools >= 3.0-7mdk
%define requires2 mkinitrd >= 3.4.43-10mdk
%if %{build_100}
%define requires3 bootloader-utils >= 1.6
%else
%define requires3 bootloader-utils >= 1.9
%endif
%define requires4 sysfsutils module-init-tools >= 0.9.15

%define kprovides kernel = %{krealversion}, alsa

BuildRoot: %{_tmppath}/%{name}-%{krealversion}-build
Provides: module-info, %kprovides
Autoreqprov: no
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4
BuildRequires: gcc module-init-tools >= 0.9.15

%description
The kernel package contains the Linux kernel (vmlinuz), the core of your
Mandriva Linux operating system. The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

#
# kernel-smp: Symmetric MultiProcessing kernel
#

%package -n %{kname}-smp-%{mdkversion}
Summary: The Linux Kernel compiled for SMP machines.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-smp-%{mdkversion}
This package includes a SMP version of the Linux %{krealversion} kernel. It is
required only on machines with two or more CPUs, although it should work
fine on single-CPU boxes.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-secure-%{mdkversion}
Summary: The Linux Kernel compiled for SECURE machines.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-secure-%{mdkversion}
This package includes a SECURE version of the Linux %{krealversion}
kernel. This package add options for kernel that make it more secure
for servers and such. See :

http://www.nsa.gov/selinux/

for list of features we have included.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

#
# kernel-xbox: XBox kernel
# 

%package -n %{kname}-xbox-%{mdkversion}
Summary: The version of the Linux kernel used on XBox machines.
Group: System/Kernel and hardware
Url: http://peoples.mandrakesoft.com/~sbenedict/XBox/
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-xbox-%{mdkversion}
This package includes a modified version of the Linux kernel.
This kernel is used for XBox machines only and should not
be used for a normal x86 machine.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-i586-up-1GB-%{mdkversion}
Summary: The Linux Kernel compiled for up with less than 1GB.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i586-up-1GB-%{mdkversion}
This package includes a kernel that has appropriate configuration options
enabled for the typical single processor desktop with up to 1GB of memory.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-i686-up-4GB-%{mdkversion}
Summary: The Linux Kernel compiled for up with 4GB.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i686-up-4GB-%{mdkversion}
This package includes a kernel that has appropriate configuration 
options enabled for the typical single processor machine with memory 
between 1GB and 4GB.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-i686-up-1GB-%{mdkversion}
Summary: The Linux Kernel compiled for up with less than 1GB.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i686-up-1GB-%{mdkversion}
This package includes a kernel that has appropriate configuration 
options enabled for the typical single processor machine with less 
than 1GB of memory.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-i686-smp-1GB-%{mdkversion}
Summary: The Linux Kernel compiled for up with less than 1GB.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i686-smp-1GB-%{mdkversion}
This package includes a kernel that has appropriate configuration 
options enabled for the typical multi processor (or Hyper-Threading) 
machines with less than 1GB of memory.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

#
# kernel-power5: Power5 kernel
#

%package -n %{kname}-power5-%{mdkversion}
Summary: The POWER5 optimized kernel
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-power5-%{mdkversion}
The kernel-power5 package contains the POWER5 optimized kernel for
IBM OpenPower series systems.

%{klinus_notice}

#
# kernel-source: kernel sources
#

%package -n %{kname}-source-%{mdkversion}
Version: %{rpmversion}
Release: %{rpmrelease}
Provides: %{kname}-source, kernel-source
Requires: glibc-devel, ncurses-devel, make, gcc, perl
Summary: The source code for the Linux kernel.
Group: Development/Kernel
Autoreqprov: no

%description -n %{kname}-source-%{mdkversion}
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned to
your particular hardware, if you are so inclined (and you know what you're
doing).

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-source-stripped-%{mdkversion}
Version: %{rpmversion}
Release: %{rpmrelease}
Provides: %{kname}-source, kernel-source
Provides: %{kname}-source-2.%{major}
Requires: glibc-devel, ncurses-devel, make, gcc, perl
Summary: The source code of the Linux kernel stripped for post build.
Group: Development/Kernel
Autoreqprov: no

%description -n %{kname}-source-stripped-%{mdkversion}
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned to
your particular hardware, if you are so inclined (and you know what you're
doing).

%{klinus_notice}

#
# kernel-doc: documentation for the Linux kernel
#

%package -n %{kname}-doc
Version: %{version}
Release: %{release}
Summary: Various documentation bits found in the kernel source.
Group: Books/Computer books

%description -n %{kname}-doc
This package contains documentation files form the kernel source. Various
bits of information about the Linux kernel and the device drivers shipped
with it are documented in these files. You also might want install this
package if you need a reference to the options that can be passed to Linux
kernel modules at load time.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c

pushd %src_dir
%if %use_patch
%patch1 -p1
%endif
popd

# Put here patchlevel patches

# PATCH END
#
# Setup Begin
#

pushd ${RPM_SOURCE_DIR}

# FIXME: The right way to it would be the loop only running through the arch's
# .config files. But the kernel build functions (defined in the %build
# section) expect the .config files exactly the way the current loop does.
# The build functions need to be fixed first.
for i in kernel-%{kversion}-*.config; do
	cp $i %{build_dir}/linux-%{kversion}/arch/%{target_arch}/$(basename $i)
done
popd

# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" linux-%{kversion}/Makefile

# get rid of unwanted files
# XXX: This was used in the previous mdv's kernel, doesn't seem needed any
# more. Let's keep it commented for now, can be totally removed if after
# more testing.
# find . -name '*~' -o -name '*.orig' -o -name '*.append' |xargs rm -f

%if %build_kheaders

kheaders_dirs=`echo $PWD/linux-%{kversion}/include/{asm-*,linux,sound}`

install -d kernel-headers/
cp -a $kheaders_dirs kernel-headers/
tar cf kernel-headers-%mdkversion.tar kernel-headers/
bzip2 -9f kernel-headers-%mdkversion.tar
rm -rf kernel-headers/
# build_kheaders
%endif

%build
# Common target directories
%define _kerneldir /usr/src/linux-%{KVERREL}
%define _bootdir /boot
%ifarch ia64
%define _efidir %{_bootdir}/efi/mandrake
%endif
%define _modulesdir /lib/modules
%define _savedheaders ../../savedheaders/

# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_source %{temp_root}%{_kerneldir}
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}

PrepareKernel() {
	name=$1
	extension=$2
	# FIXME: Should be removed when we adopt a standard name for the
        # .config files
	config_name="kernel-%{kversion}-%{target_arch}.config"
	echo "Prepare compilation of kernel $extension"

	# We can't use only defconfig anyore because we have the autoconf patch,

	if [ "$name" ]; then
		config_name="kernel-%{kversion}-%{target_arch}-$name.config"
	fi

	# make sure EXTRAVERSION says what we want it to say
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION =.*/EXTRAVERSION = -$extension/" Makefile

	%smake -s mrproper
	cp arch/%{target_arch}/$config_name .config
	%smake oldconfig
}

BuildKernel() {
	KernelVer=$1
	echo "Building kernel $KernelVer"

	%kmake all

	## Start installing stuff
	install -d %{temp_boot}
	install -m 644 System.map %{temp_boot}/System.map-$KernelVer
	install -m 644 .config %{temp_boot}/config-$KernelVer

	%ifarch alpha
	cp -f arch/alpha/boot/vmlinux.gz %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch ia64
       	install -d %{temp_root}%{_efidir}
       	cp -f vmlinux.gz %{temp_root}%{_efidir}/vmlinuz-$KernelVer
       	pushd %{temp_boot}
       	ln -s %{_efidir}/vmlinuz-$KernelVer vmlinuz-$KernelVer
       	popd
       	%endif
	%ifarch sparc sparc64
	gzip -9c vmlinux > %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch ppc
	cp -f vmlinux %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch %{ix86}
	cp -f arch/i386/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch x86_64
	cp -f arch/x86_64/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch powerpc
	cp -f vmlinux %{temp_boot}/vmlinuz-$KernelVer
	%endif

	# modules
	install -d %{temp_modules}/$KernelVer
	%smake INSTALL_MOD_PATH=%{temp_root} KERNELRELEASE=$KernelVer modules_install 
}

SaveHeaders() {
	flavour=$1
	flavour_name="`echo $flavour | sed 's/-/_/g'`"
%if %build_source
	HeadersRoot=%{temp_source}/savedheaders
	HeadersArch=$HeadersRoot/%{target_cpu}/$flavour
	echo "Saving hearders for $flavour %{target_cpu}"

	# deal with the kernel headers that are version specific
	install -d $HeadersArch
	install -m 644 include/linux/autoconf.h $HeadersArch/autoconf.h
	install -m 644 include/linux/version.h $HeadersArch/version.h
    	echo "%{target_cpu} $flavour_name %{_savedheaders}%{target_cpu}/$flavour/" >> $HeadersRoot/list
%endif
}

CreateFiles() {
	kernversion=$1
	output=../kernel_files.$kernversion

	echo "%defattr(-,root,root)" > $output
	echo "%{_bootdir}/config-${kernversion}" >> $output
	echo "%{_bootdir}/vmlinuz-${kernversion}" >> $output
%ifarch ia64
	echo "%{_efidir}/vmlinuz-${kernversion}" >> $output
%endif
	echo "%{_bootdir}/System.map-${kernversion}" >> $output
	echo "%dir %{_modulesdir}/${kernversion}/" >> $output
	echo "%{_modulesdir}/${kernversion}/kernel" >> $output
	echo "%{_modulesdir}/${kernversion}/modules.*" >> $output
	echo "%doc README.kernel-sources" >> $output
	echo "%doc README.MandrivaLinux" >> $output
}

CreateKernel() {
	flavour=$1

	if [ "$flavour" = "up" ]; then
		KernelVer=%{KVERREL}
		PrepareKernel "" %realrelease
	elif [ "$flavour" = "power5" ]; then
		KernelVer=%{KVERREL}p5
		PrepareKernel $flavour %{realrelease}p5
	else
		KernelVer=%{KVERREL}$flavour
		PrepareKernel $flavour %{realrelease}$flavour
	fi

	BuildKernel $KernelVer
	SaveHeaders $flavour
        CreateFiles $KernelVer
}


CreateKernelNoName() {
	arch=$1
	nprocs=$2
	memory=$3

        name=$arch-$nprocs-$memory
	extension="%realrelease-$name"

	KernelVer="%{KVERREL}-$arch-$nprocs-$memory"
	PrepareKernel $name $extension
	BuildKernel $KernelVer
	SaveHeaders $name
        CreateFiles $KernelVer
}

###
# DO it...
###

# Create a simulacro of %buildroot
rm -rf %{temp_root}
install -d %{temp_root}

#make sure we are in the directory
cd %src_dir

%if %build_power5
CreateKernel power5
%endif

%if %build_smp
CreateKernel smp
%endif

%if %build_i586_up_1GB
CreateKernelNoName i586 up 1GB
%endif

%if %build_i686_up_4GB
CreateKernelNoName i686 up 4GB
%endif

%if %build_xbox
CreateKernel xbox
%endif

%if %build_up
CreateKernel up
%endif

# We don't make to repeat the depend code at the install phase
%if %build_source
PrepareKernel "" %{realrelease}custom
# From > 2.6.13 prepare-all is deprecated and relies on include/linux/autoconf
# To have modpost and others scripts, one has to use the target scripts
%smake -s prepare
%smake -s scripts
%endif

###
### install
###
%install
install -m 644 %{SOURCE4}  .
install -m 644 %{SOURCE5}  .

cd %src_dir
# Directories definition needed for installing
%define target_source %{buildroot}/%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source} 

tar cf - . | tar xf - -C %{target_source}
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship

# first architecture files
for i in arm cris mips mips64 parisc s390 s390x sh sh64 arm26 h8300 m68knommu v850 m32r frv; do
	rm -rf %{target_source}/arch/$i
	rm -rf %{target_source}/include/asm-$i
done
# ppc needs m68k headers
rm -rf %{target_source}/arch/m68k

# remove config split dir
rm -rf %{target_source}/include/config

# other misc files
rm -f %{target_source}/{.config.old,.config.cmd,.tmp_gas_check}

pushd %{target_source}/include/linux ; {
install -m 644 %{SOURCE15} rhconfig.h
rm -rf autoconf.h version.h
# Create autoconf.h file
echo '#include <linux/rhconfig.h>' > autoconf.h
sed 's,$,autoconf.h,' %{_savedheaders}list | awk -f %{SOURCE16} >> autoconf.h
# Create version.h
echo "#include <linux/rhconfig.h>" > version.h
loop_cnt=0
for i in up smp secure i686-up-4GB i686-up-1GB i686-smp-1GB i586-up-1GB power5; do
	if [ -d %{_savedheaders}%{target_cpu}/$i -a \
	     -f %{_savedheaders}%{target_cpu}/$i/version.h ]; then
		name=`echo $i | sed 's/-/_/g'`
		if [ $loop_cnt = 0 ]; then
      			buf="#if defined(__module__$name)"
    		else
 	     		buf="#elif defined(__module__$name)"
    		fi
		echo "$buf" >> version.h
		grep UTS_RELEASE %{_savedheaders}%{target_cpu}/$i/version.h >> version.h
		loop_cnt=$[loop_cnt + 1]
	fi
done
#write last lines
if [ $loop_cnt -eq 0 ]; then
	echo "You need to build at least one kernel"
	exit 1;
fi
echo "#else" >> version.h
echo '#define UTS_RELEASE "'%{KVERREL}custom'"' >> version.h
echo "#endif" >> version.h

# Any of the version.h are ok, as they only differ in the first line
ls %{_savedheaders}%{target_cpu}/*/version.h | head -n 1 | xargs grep -v UTS_RELEASE >> version.h
rm -rf %{_savedheaders}
} ; popd
#endif %build_source
%endif

# gzipping modules
find %{target_modules} -name "*.ko" | xargs gzip -9

# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be

for i in %{target_modules}/*; do
  rm -f $i/build $i/source $i/modules.*
done

# sniff, if we gzipped all the modules, we change the stamp :(
# we really need the depmod -ae here

pushd %{target_modules}
for i in *; do
	/sbin/depmod-25 -u -ae -b %{buildroot} -r -F %{target_boot}/System.map-$i $i
	echo $?
done

for i in *; do
	pushd $i
	echo "Creating module.description for $i"
	modules=`find . -name "*.ko.gz"`
	echo $modules | xargs /sbin/modinfo-25 \
	| perl -lne 'print "$name\t$1" if $name && /^description:\s*(.*)/; $name = $1 if m!^filename:\s*(.*)\.k?o!; $name =~ s!.*/!!' > modules.description
	popd
done
popd

###
### clean
###

%clean
rm -rf %{buildroot}
# We don't want to remove this, the whole reason of its existence is to be 
# able to do several rpm --short-circuit -bi for testing install 
# phase without repeating compilation phase
#rm -rf %{temp_root} 

###
### scripts
###

%if %{build_100}
%define options_preun -a -R -S -c
%define options_post  -a -s -c
%else
%define options_preun -R
#%define options_post -C
%endif

%preun
/sbin/installkernel %options_preun %{KVERREL}
exit 0

%post
/sbin/installkernel %options_post %{KVERREL}

%postun
/sbin/kernel_remove_initrd %{KVERREL}


%preun -n %{kname}-smp-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}smp
exit 0

%post -n %{kname}-smp-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}smp

%postun -n %{kname}-smp-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}smp

%preun -n %{kname}-xbox-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}xbox
exit 0

%post -n %{kname}-xbox-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}xbox

%postun -n %{kname}-xbox-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}xbox

%preun -n %{kname}-secure-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}secure
exit 0

%post -n %{kname}-secure-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}secure

%postun -n %{kname}-secure-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}secure


%preun -n %{kname}-i586-up-1GB-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}-i586-up-1GB
exit 0

%post -n %{kname}-i586-up-1GB-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}-i586-up-1GB

%postun -n %{kname}-i586-up-1GB-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}-i586-up-1GB


%preun -n %{kname}-i686-up-4GB-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}-i686-up-4GB
exit 0

%post -n %{kname}-i686-up-4GB-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}-i686-up-4GB

%postun -n %{kname}-i686-up-4GB-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}-i686-up-4GB


%preun -n %{kname}-i686-up-1GB-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}-i686-up-1GB
exit 0

%post -n %{kname}-i686-up-1GB-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}-i686-up-1GB

%postun -n %{kname}-i686-up-1GB-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}-i686-up-1GB

%preun -n %{kname}-i686-smp-1GB-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}-i686-smp-1GB
exit 0

%post -n %{kname}-i686-smp-1GB-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}-i686-smp-1GB

%postun -n %{kname}-i686-smp-1GB-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}-i686-smp-1GB


%preun -n %{kname}-power5-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}p5
exit 0

%post -n %{kname}-power5-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}p5

%postun -n %{kname}-power5-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}p5


%post -n %{kname}-source-%{mdkversion}
cd /usr/src
rm -f linux
ln -snf linux-%{KVERREL} linux
/sbin/service kheader start 2>/dev/null >/dev/null || :
# we need to create /build only when there is a source tree.

for i in /lib/modules/%{KVERREL}*; do
	if [ -d $i ]; then
		ln -sf /usr/src/linux-%{KVERREL} $i/build
		ln -sf /usr/src/linux-%{KVERREL} $i/source
	fi
done

%postun -n %{kname}-source-%{mdkversion}
if [ -L /usr/src/linux ]; then 
    if [ -L /usr/src/linux -a `ls -l /usr/src/linux 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux
    fi
fi
# we need to delete <modules>/build at unsinstall
for i in /lib/modules/%{KVERREL}*/{build,source}; do
	if [ -L $i ]; then
		rm -f $i
	fi
done
exit 0

%post -n %{kname}-source-stripped-%{mdkversion}
cd /usr/src
rm -f linux
ln -snf linux-%{KVERREL} linux
/sbin/service kheader start 2>/dev/null >/dev/null || :
# we need to create /build only when there is a source tree.

for i in /lib/modules/%{KVERREL}*; do
	if [ -d $i ]; then
		ln -sf /usr/src/linux-%{KVERREL} $i/build
		ln -sf /usr/src/linux-%{KVERREL} $i/source
	fi
done

%postun -n %{kname}-source-stripped-%{mdkversion}
if [ -L /usr/src/linux ]; then 
    if [ -L /usr/src/linux -a `ls -l /usr/src/linux 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux
    fi
fi
# we need to delete <modules>/{build,source} at unsinstall
for i in /lib/modules/%{KVERREL}*/{build,source}; do
	if [ -L $i ]; then
		rm -f $i
	fi
done
exit 0

###
### file lists
###

%if %build_up
%files -f kernel_files.%{KVERREL}
%endif

%if %build_smp
%files -n %{kname}-smp-%{mdkversion} -f kernel_files.%{KVERREL}smp
%endif

%if %build_xbox
%files -n %{kname}-xbox-%{mdkversion} -f kernel_files.%{KVERREL}xbox
%endif

%if %build_secure
%files -n %{kname}-secure-%{mdkversion} -f kernel_files.%{KVERREL}secure
%endif

%if %build_i586_up_1GB
%files -n %{kname}-i586-up-1GB-%{mdkversion} -f kernel_files.%{KVERREL}-i586-up-1GB
%endif

%if %build_i686_up_4GB
%files -n %{kname}-i686-up-4GB-%{mdkversion} -f kernel_files.%{KVERREL}-i686-up-4GB
%endif

%if %build_power5
%files -n %{kname}-power5-%{mdkversion} -f kernel_files.%{KVERREL}p5
%endif


%if %build_source
%files -n %{kname}-source-%{mdkversion}
%defattr(-,root,root)
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/.config
%{_kerneldir}/.gitignore
%{_kerneldir}/.kconfig.d
%{_kerneldir}/.kernelrelease
%{_kerneldir}/Kbuild
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Documentation
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%{_kerneldir}/arch/alpha
%{_kerneldir}/arch/i386
%{_kerneldir}/arch/ia64
%{_kerneldir}/arch/ppc
%{_kerneldir}/arch/powerpc
%{_kerneldir}/arch/sparc
%{_kerneldir}/arch/sparc64
%{_kerneldir}/arch/x86_64
%{_kerneldir}/arch/xtensa
%{_kerneldir}/arch/um
%{_kerneldir}/block
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/fs
%{_kerneldir}/init
%{_kerneldir}/ipc
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/security
%{_kerneldir}/scripts
%{_kerneldir}/sound
%{_kerneldir}/usr
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm
%{_kerneldir}/include/asm-alpha
%{_kerneldir}/include/asm-generic
%{_kerneldir}/include/asm-i386
%{_kerneldir}/include/asm-ia64
# This is needed by ppc
%{_kerneldir}/include/asm-m68k
%{_kerneldir}/include/asm-ppc
%{_kerneldir}/include/asm-powerpc
%{_kerneldir}/include/asm-sparc
%{_kerneldir}/include/asm-sparc64
%{_kerneldir}/include/asm-x86_64
%{_kerneldir}/include/asm-xtensa
%{_kerneldir}/include/asm-um
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/video
%{_kerneldir}/include/media
%{_kerneldir}/include/mtd
%{_kerneldir}/include/rxrpc
%{_kerneldir}/include/keys
%{_kerneldir}/include/rdma
%doc README.kernel-sources
%doc README.MandrivaLinux

# source-stripped
%files -n %{kname}-source-stripped-%{mdkversion}
%defattr(-,root,root)
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/.config
%{_kerneldir}/.kconfig.d
%{_kerneldir}/.kernelrelease
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Documentation
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%{_kerneldir}/arch/alpha
%{_kerneldir}/arch/i386
%{_kerneldir}/arch/ia64
%{_kerneldir}/arch/ppc
%{_kerneldir}/arch/powerpc
%{_kerneldir}/arch/sparc
%{_kerneldir}/arch/sparc64
%{_kerneldir}/arch/x86_64
%{_kerneldir}/arch/um
%{_kerneldir}/drivers/char
%{_kerneldir}/drivers/scsi
%{_kerneldir}/scripts
%{_kerneldir}/usr
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm
%{_kerneldir}/include/asm-alpha
%{_kerneldir}/include/asm-generic
%{_kerneldir}/include/asm-i386
%{_kerneldir}/include/asm-ia64
# This is needed by ppc
%{_kerneldir}/include/asm-m68k
%{_kerneldir}/include/asm-ppc
%{_kerneldir}/include/asm-powerpc
%{_kerneldir}/include/asm-sparc
%{_kerneldir}/include/asm-sparc64
%{_kerneldir}/include/asm-x86_64
%{_kerneldir}/include/asm-um
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/video
%{_kerneldir}/include/media
%{_kerneldir}/include/rxrpc
%doc README.kernel-sources
%doc README.MandrivaLinux
#endif %build_source
%endif

%if %build_doc
%files -n %{kname}-doc
%defattr(-,root,root)
%doc linux-%{kversion}/Documentation/*
%endif

%changelog
### REMOVE THE PATCHLEVEL DEFINITION ABOVE ###
* Mon Jun 19 2006 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.17-1mdk
   - Updates to 2.6.17
   - Version reset: when I started with kernel-linus I wasn't too
     experienced with RPM packages and thought that packages' version
     should never been reset. Doing it now.

# Local Variables:
# rpm-spec-insert-changelog-version-with-shell: t
# End:
